@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: haddock
-version: 2.9.2
-id: haddock-2.9.2-e82494b75ce7287c801c0edc7fbf0ddd
+version: 2.11.0
+id: haddock-2.11.0-9d4537d32519f02edbbf4685ff2d1a23
 
 license: BSD3
 copyright: (c) Simon Marlow, David Waern
@@ -9,16 +9,16 @@ maintainer: David Waern <david.waern@gmail.com>
 stability: experimental
 homepage: http://www.haskell.org/haddock/
 package-url:
+synopsis: A documentation-generation tool for Haskell libraries
 description: Haddock is a documentation-generation tool for Haskell
              libraries
-category: Development
+category: Documentation
 author: Simon Marlow, David Waern
 pkgpath: devel/haddock
 exposed: True
 exposed-modules: Documentation.Haddock
 hidden-modules: Main Haddock.Interface Haddock.Interface.Rename
-                Haddock.Interface.Create Haddock.Interface.ExtractFnArgDocs
-                Haddock.Interface.AttachInstances Haddock.Interface.Rn
+                Haddock.Interface.Create Haddock.Interface.AttachInstances
                 Haddock.Interface.LexParseRn Haddock.Interface.ParseModuleHeader
                 Haddock.Lex Haddock.Parse Haddock.Utils Haddock.Backends.Xhtml
                 Haddock.Backends.Xhtml.Decl Haddock.Backends.Xhtml.DocMarkup
@@ -29,28 +29,29 @@ hidden-modules: Main Haddock.Interface Haddock.Interface.Rename
                 Haddock.ModuleTree Haddock.Types Haddock.Doc Haddock.Version
                 Haddock.InterfaceFile Haddock.Options Haddock.GhcUtils
                 Haddock.Convert Paths_haddock
-import-dirs: /usr/local/lib/ghc/haddock-2.9.2
-library-dirs: /usr/local/lib/ghc/haddock-2.9.2
-hs-libraries: HShaddock-2.9.2
+trusted: False
+import-dirs: /usr/local/lib/ghc/haddock-2.11.0
+library-dirs: /usr/local/lib/ghc/haddock-2.11.0
+hs-libraries: HShaddock-2.11.0
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: Cabal-1.10.2.0-170104cbbfa46559cdde1ceda82c4ee2
-         array-0.3.0.2-ecfce597e0f16c4cd1df0e1d22fd66d4
-         base-4.3.1.0-912d55d387093f740e3bcd2ffbf1dd83
-         containers-0.4.0.0-18deac99a132f04751d862b77aab136e
-         directory-1.1.0.0-9b4fc50fd8f1413dca2a5e01dd665f6d
-         filepath-1.2.0.0-679ac50c41ba31bfc69abf444d9852e4
-         ghc-7.0.4-291187112fede2c5e1e6c5eaeb1acaa7
-         ghc-paths-0.1.0.8-a7d3cc0d7b889fdea60d782c8c0068e3
-         pretty-1.0.1.2-abc7c632374e50e1c1927987c2651f0f
-         xhtml-3000.2.0.1-82694a5e5183c02e3c96eef29869641c
+depends: Cabal-1.14.0-90071ef9b434add24a18ee48575f67a1
+         array-0.4.0.0-0b6c5ca7e879a14d110ca4c001dd9297
+         base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
+         containers-0.4.2.1-75f143aa39a3e77a1ce2300025bdd8ce
+         directory-1.1.0.2-da0a8c62c2b42ae7a3b538f5fee58422
+         filepath-1.3.0.0-f998e5510c76a98913f57b14b4f16c57
+         ghc-7.4.2-ff17ca7533156fa235968f1506515446
+         ghc-paths-0.1.0.8-fe805223477a58f16f6dd6c1c6fe4446
+         pretty-1.1.1.0-91ed62f0481a81d292d550eec35ee75b
+         xhtml-3000.2.1-a09b68735bfe2ec1579e0c7d07daf50e
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-haddock-2.9.2/html/haddock.haddock
-haddock-html: /usr/local/share/doc/hs-haddock-2.9.2/html
+haddock-interfaces: /usr/local/share/doc/hs-haddock-2.11.0/html/haddock.haddock
+haddock-html: /usr/local/share/doc/hs-haddock-2.11.0/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
